#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HStringTemplate
version:              0.8.8
visibility:           public
id:                   HStringTemplate-0.8.8-LLUf8BbFlSVHy7P2WYUOBm
key:                  HStringTemplate-0.8.8-LLUf8BbFlSVHy7P2WYUOBm
license:              BSD-3-Clause
maintainer:           s.clover@gmail.com
author:               Sterling Clover
synopsis:             StringTemplate implementation in Haskell.
description:          A port of the Java library by Terrence Parr.
category:             Text
abi:                  a0b5183d76d77933cb5e63e5ca5773eb
exposed:              True
exposed-modules:
    Text.StringTemplate Text.StringTemplate.Base
    Text.StringTemplate.Classes Text.StringTemplate.GenericStandard
    Text.StringTemplate.QQ

hidden-modules:
    Text.StringTemplate.Instances Text.StringTemplate.Group
    Text.StringTemplate.Renderf

import-dirs:          /usr/lib/ghc-9.6.6/site-local/HStringTemplate-0.8.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/HStringTemplate-0.8.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/HStringTemplate-0.8.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hstringtemplate
hs-libraries:         HSHStringTemplate-0.8.8-LLUf8BbFlSVHy7P2WYUOBm
depends:
    array-0.5.6.0 base-4.18.2.1
    blaze-builder-0.4.4.1-LpEq21LNRHq8DXqqJhoUXc bytestring-0.11.5.3
    containers-0.6.7 deepseq-1.4.8.1 directory-1.3.8.5
    filepath-1.4.300.1 mtl-2.3.1
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC parsec-3.1.16.1
    pretty-1.1.3.6 syb-0.7.3-45RHZbqQsU9HukQlnlXSjw
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    void-0.7.4-Ab78HEYVlxC2PerDGXO6Wd

haddock-interfaces:
    /usr/share/doc/haskell-hstringtemplate/html/HStringTemplate.haddock

haddock-html:         /usr/share/doc/haskell-hstringtemplate/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

